<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="编号" prop="impaCode">
        <el-input maxlength="100" v-model="queryParams.impaCode" placeholder="请输入编号" clearable
          @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="描述" prop="impaNotes">
        <el-input maxlength="100" v-model="queryParams.impaNotes" placeholder="请输入描述" clearable
          @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8" style="min-height:32px">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Plus" @click="handleAdd" v-hasPermi="['impa:impa:add']">新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="Edit" :disabled="single" @click="handleUpdate"
          v-hasPermi="['impa:impa:edit']">修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['impa:impa:remove']">删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="Download" @click="handleExport" v-hasPermi="['impa:impa:export']">导出
        </el-button>
      </el-col>
      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="impaList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" v-hasPermi="['impa:impa:edit', 'impa:impa:remove']" />
      <!-- <el-table-column label="主键id" align="center" prop="id" /> -->
      <el-table-column label="编号" align="center" prop="impaCode" />
      <el-table-column label="描述" align="center" prop="impaNotes" />
      <!-- <el-table-column label="状态" align="center" key="status">
        <template #default="scope">
          <el-switch
            v-model="scope.row.status"
            active-value="0"
            inactive-value="1"
            @change="handleStatusChange(scope.row)"
          ></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="状态" align="center" prop="status" /> -->
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="200" fixed="right"
        v-hasPermi="['impa:impa:edit', 'impa:impa:remove']">
        <template #default="scope">
          <!-- <el-button
            link
            icon="View"
            @click="handleView(scope.row)"
            v-hasPermi="['impa:impa:query']"
            >详细
          </el-button> -->
          <el-button link type="success" icon="Edit" @click="handleUpdate(scope.row)" v-hasPermi="['impa:impa:edit']">修改
          </el-button>
          <el-button link type="danger" icon="Delete" @click="handleDelete(scope.row)"
            v-hasPermi="['impa:impa:remove']">删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" v-model:page="queryParams.pageNum"
      v-model:limit="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改物料管理-物料目录对话框 -->
    <el-dialog  :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="impaRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="编号" prop="impaCode">
          <el-input maxlength="100" v-model="form.impaCode" placeholder="请输入编号" />
        </el-form-item>
        <el-form-item label="描述" prop="impaNotes">
          <el-input maxlength="300" v-model="form.impaNotes" type="textarea" placeholder="请输入描述" />
        </el-form-item>
        <!-- <el-form-item label="删除标志" prop="delFlag">
          <el-input
            v-model="form.delFlag"
            placeholder="请输入删除标志"
            
          />
        </el-form-item> -->
        <el-form-item label="备注" prop="remark">
          <el-input maxlength="300" v-model="form.remark" placeholder="请输入备注" type="textarea" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="IMPACatalog">
import {
  listImpa,
  getImpa,
  delImpa,
  addImpa,
  updateImpa,
  downloadImpa,
} from "@/api/impa/impa";

const { proxy } = getCurrentInstance();
const impaList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    impaCode: null,
    impaNotes: null,
    status: null,
  },
  rules: {
    impaCode: [
      {
        required: true,
        message: "编号不能为空",
        trigger: "blur",
      },
    ],
    impaNotes: [
      {
        required: true,
        message: "描述不能为空",
        trigger: "blur",
      },
    ],
  },
});
const { queryParams, form, rules } = toRefs(data);
const baseUrl = import.meta.env.VITE_APP_BASE_API;

/** 查询物料管理-物料目录列表 */
function getList() {
  loading.value = true;
  listImpa(queryParams.value).then((response) => {
    impaList.value = response.rows;
    total.value = response.total;
    loading.value = false;
  });
}

function addList() {
  loading.value = true;
  listImpa(queryParams.value)
    .then((response) => {
      impaList.value.push(...response.rows);
      total.value = response.total;
      if (impaList.value.length >= total.value) finished.value = true;
      loading.value = false;
    })
    .catch((response) => {
      loading.value = false;
    });
}

// 下拉刷新
function handlePullDownRefresh() {
  queryParams.value.pageNum = 1;
  impaList.value = [];
  addList();
}

// 滚动到底部的事件
function handleReachBottom() {
  queryParams.value.pageNum++;
  addList();
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    impaCode: null,
    impaNotes: null,
    status: "0",
    delFlag: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null,
    remark: null,
  };
  proxy.resetForm("impaRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map((item) => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加物料管理-物料目录";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const id = row.id || ids.value;
  getImpa(id).then((response) => {
    form.value = response.data;
    open.value = true;
    title.value = "修改物料管理-物料目录";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["impaRef"].validate((valid) => {
    if (valid) {
      if (form.value.id != null) {
        updateImpa(form.value).then((response) => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addImpa(form.value).then((response) => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const ids = row.id || ids.value;
  proxy.$modal
    .confirm('是否确认删除物料管理-物料目录编号为"' + ids + '"的数据项？')
    .then(function () {
      return delImpa(ids);
    })
    .then(() => {
      getList();
      proxy.$modal.msgSuccess("删除成功");
    })
    .catch(() => { });
}

/** 导出按钮操作 */
function handleExport() {
  downloadImpa(queryParams.value);
  // proxy.download('impa/impa/export', {
  //   ...queryParams.value
  // }, `impa_${new Date().getTime()}.xlsx`)
}

/** 详细按钮操作 */
function handleView(row) { }

/** 状态修改  */
function handleStatusChange(row) {
  let text = row.status === "0" ? "启用" : "停用";
  proxy.$modal
    .confirm("确认要" + text + "编号【" + row.impaCode + "】?")
    .then(function () {
      return updateImpa(row);
    })
    .then(() => {
      proxy.$modal.msgSuccess(text + "成功");
    })
    .catch(function () {
      row.status = row.status === "0" ? "1" : "0";
    });
}
function initialData() {
  getList();
}

onActivated(() => {
  //// console.log("onActivated")
  initialData();
})
onMounted(() => {
  //// console.log("onMounted")
  initialData();
})
</script>

